asMap method
An unmodifiable Map view of this list. The map uses the indices of this list as keys and the corresponding objects as values. The Map.keys Iterable iterates the indices of this list in numerical order.
Implementation
Map<int, T> asMap() => _list.asMap();