ObservableSet<T> class
- Mixed-in types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isEmpty → bool
-
no setter
- isNotEmpty → bool
-
no setter
- length → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
set
→ Set<
T> -
no setter
Methods
-
add(
T toAdd) → bool -
addAll(
Iterable< T> toAdd) → void -
addAllWhere(
Iterable< T> toAdd, bool condition(T t, Set<T> currSet)) → void -
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
change<
G> (G operation()) → G -
contains(
int id) → bool -
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
remove(
T toRemove) → bool -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
removeWhere(
bool condition(T t, Set< T> currSet)) → void -
reset(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
update<
T> (T updater()) → T -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited