DataStack<T> class

Constructors

DataStack([List<T>? values])

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
isNotEmpty bool
no setter
length int
no setter
list List<T>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

glance() → T?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pop() → T?
popAll() → void
popUntil(bool test(T stackElement)) → void
stack(T value) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited