Appends all objects of iterable to the end of this list.
Extends the length of the list by the number of objects in iterable. The list must be growable.
An unmodifiable Map view of this list.
The map uses the indices of this list as keys and the corresponding objects as values. The Map.keys Iterable iterates the indices of this list in numerical order.
Whether the collection contains an element equal to element.
This operation will check each element in order for being equal to element, unless it has a more efficient way to find an element equal to element. Stops iterating on the first equal element.
The equality used to determine whether element is equal to an element of the iterable defaults to the Object.== of the element.
Some types of iterable may have a different equality used for its elements. For example, a Set may have a custom equality (see Set.identity) that its contains uses. Likewise the Iterable returned by a Map.keys call should use the same equality that the Map uses for keys.
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
Inserts element at position index in this list.
This increases the length of the list by one and shifts all objects at or after the index towards the end of the list.
The list must be growable. The index value must be non-negative and no greater than length.